@@ -103,6 +103,20 @@ def test_import_jsonfiles_parallel(
     validate_stack_import(render, stack, tilespecs)
     renderapi.stack.delete_stack(stack, render=render)
 
+def test_bbox_transformed(render, render_example_tilespec_and_transforms):
+    (tilespecs, tforms) = render_example_tilespec_and_transforms
+    ts = tilespecs[0]
+    xy = ts.bbox_transformed(ndiv_inner=0,tf_limit=0)
+    assert xy.shape == (5,2)
+    assert np.abs((xy[2,:]-np.array([ts.width,ts.height])).sum()) < 1e-10
+    xy = ts.bbox_transformed(ndiv_inner=1,tf_limit=0)
+    assert xy.shape == (9,2)
+    #xy = ts.bbox_transformed(ndiv_inner=1,tf_limit=4)
+    #assert xy.shape == (9,2)
+    #xy = ts.bbox_transformed(ndiv_inner=1,tf_limit=None)
+    #assert xy.shape == (9,2)
+
+
 def square(x):
     return x**2
 #this test was added in order to validate that multiple WithPools would work
