@@ -360,7 +360,7 @@ def test_section_image(render, teststack, **kwargs):
 
 
 def test_section_image_options(render, teststack):
-    img = test_section_image(render, teststack, filter=True,
+    test_section_image(render, teststack, filter=True,
                              maxTileSpecsToRender=50)
 
 
@@ -457,4 +457,21 @@ def test_put_tilespecs_and_tforms(render,render_example_tilespec_and_transforms)
 def test_put_tilespecs_fail(render):
     with pytest.raises(renderapi.errors.RenderError):
         r=renderapi.resolvedtiles.put_tilespecs('fail_stack',render=render)
+        
+def test_bad_delete(render):
+    with pytest.raises(renderapi.errors.RenderError):
+        renderapi.stack.delete_section('not_a_stack',0.0,render=render)
+
+def test_bad_get(render):
+    with pytest.raises(renderapi.errors.RenderError):
+        renderapi.stack.get_stack_metadata('not_a_stack',render=render)
+
+def test_bad_post(render):
+    sv = renderapi.stack.StackVersion()
+    with pytest.raises(renderapi.errors.RenderError):
+        renderapi.stack.set_stack_state('not_a_stack','LOADING',render=render)
+
+def test_bad_put(render):
+    with pytest.raises(renderapi.errors.RenderError):
+        renderapi.stack.clone_stack('not_a_stack','not_getting_here',render=render)
         
\ No newline at end of file
