@@ -6,7 +6,7 @@ import requests
 import logging
 from .render import format_baseurl, renderaccess
 from .errors import RenderError
-from .utils import NullHandler
+from .utils import NullHandler, get_json, put_json, rest_delete
 import json
 
 logger = logging.getLogger(__name__)
@@ -41,13 +41,8 @@ def get_matchcollection_owners(host=None, port=None,
     """
     request_url = format_baseurl(host, port) + \
         "/matchCollectionOwners"
-    r = session.get(request_url)
-    try:
-        return r.json()
-    except Exception as e:
-        logger.error(e)
-        logger.error(r.text)
-        raise RenderError(r.text)
+    return get_json(session,request_url)
+
 
 
 @renderaccess
@@ -79,13 +74,8 @@ def get_matchcollections(owner=None, host=None, port=None,
     """
     request_url = format_baseurl(host, port) + \
         "/owner/%s/matchCollections" % owner
-    r = session.get(request_url)
-    try:
-        return r.json()
-    except Exception as e:
-        logger.error(e)
-        logger.error(r.text)
-        raise RenderError(r.text)
+    return get_json(session,request_url)
+
 
 
 @renderaccess
@@ -120,17 +110,13 @@ def get_match_groupIds(matchCollection, owner=None, host=None,
     """
     request_url = format_baseurl(host, port) + \
         "/owner/%s/matchCollection/%s/groupIds" % (owner, matchCollection)
-    r = session.get(request_url)
-    try:
-        return r.json()
-    except Exception as e:
-        logger.error(e)
-        logger.error(r.text)
-        raise RenderError(r.text)
+    return get_json(session,request_url)
+
 
 
 @renderaccess
 def get_matches_outside_group(matchCollection, groupId, mergeCollections=None,
+                              stream=True,
                               owner=None, host=None,
                               port=None, session=requests.session(),
                               render=None, **kwargs):
@@ -147,6 +133,8 @@ def get_matches_outside_group(matchCollection, groupId, mergeCollections=None,
         groupId to query
     mergeCollections : :obj:`list` of :obj:`str`
         other matchCollections to aggregate into answer
+    stream: bool
+        whether to invoke streaming on get (default True)
     owner : unicode
         matchCollection owner (fallback to render.DEFAULT_OWNER)
         (note match owner != stack owner always)
@@ -170,17 +158,12 @@ def get_matches_outside_group(matchCollection, groupId, mergeCollections=None,
             owner, matchCollection, groupId)
     request_url = add_merge_collections(request_url, mergeCollections)
 
-    r = session.get(request_url)
-    try:
-        return r.json()
-    except Exception as e:
-        logger.error(e)
-        logger.error(r.text)
-        raise RenderError(r.text)
+    return get_json(session,request_url,stream=stream)
 
 
 @renderaccess
 def get_matches_within_group(matchCollection, groupId, mergeCollections=None,
+                             stream=True,
                              owner=None, host=None, port=None,
                              session=requests.session(),
                              render=None, **kwargs):
@@ -198,6 +181,8 @@ def get_matches_within_group(matchCollection, groupId, mergeCollections=None,
     mergeCollections : :obj:`list` of :obj:`str` or None
         other matchCollections
         to aggregate into answer
+    stream: bool
+        whether to invoke streaming on get (default True)
     owner : unicode
         matchCollection owner (fallback to render.DEFAULT_OWNER)
         (note match owner != stack owner always)
@@ -221,18 +206,12 @@ def get_matches_within_group(matchCollection, groupId, mergeCollections=None,
             owner, matchCollection, groupId)
     request_url = add_merge_collections(request_url, mergeCollections)
 
-    r = session.get(request_url)
-    try:
-        return r.json()
-    except Exception as e:
-        logger.error(e)
-        logger.error(r.text)
-        raise RenderError(r.text)
+    return get_json(session,request_url,stream=stream)
 
 
 @renderaccess
 def get_matches_from_group_to_group(matchCollection, pgroup, qgroup,
-                                    mergeCollections=None,
+                                    mergeCollections=None, stream=True,
                                     render=None, owner=None, host=None,
                                     port=None,
                                     session=requests.session(), **kwargs):
@@ -253,6 +232,8 @@ def get_matches_from_group_to_group(matchCollection, pgroup, qgroup,
     mergeCollections : :obj:`list` of :obj:`str` or None
         other matchCollections
         to aggregate into answer
+    stream: bool
+        whether to invoke streaming on get (default True)
     owner : unicode
         matchCollection owner (fallback to render.DEFAULT_OWNER)
         (note match owner != stack owner always)
@@ -277,13 +258,8 @@ def get_matches_from_group_to_group(matchCollection, pgroup, qgroup,
             owner, matchCollection, pgroup, qgroup)
     request_url = add_merge_collections(request_url, mergeCollections)
 
-    r = session.get(request_url)
-    try:
-        return r.json()
-    except Exception as e:
-        logger.error(e)
-        logger.error(r.text)
-        raise RenderError(r.text)
+    return get_json(session,request_url,stream=stream)
+
 
 
 def add_merge_collections(request_url, mcs):
@@ -360,17 +336,13 @@ def get_matches_from_tile_to_tile(matchCollection, pgroup, pid,
              owner, matchCollection, pgroup, pid, qgroup, qid))
     request_url = add_merge_collections(request_url, mergeCollections)
 
-    r = session.get(request_url)
-    try:
-        return r.json()
-    except Exception as e:
-        logger.error(e)
-        logger.error(r.text)
-        raise RenderError(r.text)
+    return get_json(session,request_url)
+
 
 
 @renderaccess
 def get_matches_with_group(matchCollection, pgroup, mergeCollections=None,
+                           stream=True,
                            render=None, owner=None,
                            host=None, port=None,
                            session=requests.session(), **kwargs):
@@ -387,6 +359,8 @@ def get_matches_with_group(matchCollection, pgroup, mergeCollections=None,
         source group to query
     mergeCollections : :obj:`list` of :obj:`str` or None
         other matchCollections to aggregate into answer
+    stream : bool
+        whether to invoke streaming (default=True)
     owner : unicode
         matchCollection owner (fallback to render.DEFAULT_OWNER)
         (note match owner != stack owner always)
@@ -410,13 +384,8 @@ def get_matches_with_group(matchCollection, pgroup, mergeCollections=None,
             owner, matchCollection, pgroup)
     request_url = add_merge_collections(request_url, mergeCollections)
 
-    r = session.get(request_url)
-    try:
-        return r.json()
-    except Exception as e:
-        logger.error(e)
-        logger.error(r.text)
-        raise RenderError(r.text)
+    return get_json(session,request_url,stream=stream)
+
 
 
 @renderaccess
@@ -454,13 +423,8 @@ def get_match_groupIds_from_only(matchCollection, mergeCollections=None,
         "/owner/%s/matchCollection/%s/pGroupIds" % (owner, matchCollection)
     request_url = add_merge_collections(request_url, mergeCollections)
 
-    r = session.get(request_url)
-    try:
-        return r.json()
-    except Exception as e:
-        logger.error(e)
-        logger.error(r.text)
-        raise RenderError(r.text)
+    return get_json(session,request_url)
+
 
 
 @renderaccess
@@ -499,18 +463,13 @@ def get_match_groupIds_to_only(matchCollection, mergeCollections=None,
         "/owner/%s/matchCollection/%s/qGroupIds" % (owner, matchCollection)
     request_url = add_merge_collections(request_url, mergeCollections)
 
-    r = session.get(request_url)
-    try:
-        return r.json()
-    except Exception as e:
-        logger.error(e)
-        logger.error(r.text)
-        raise RenderError(r.text)
+    return get_json(session,request_url)
+
 
 
 @renderaccess
 def get_matches_involving_tile(matchCollection, groupId, id,
-                               mergeCollections=None,
+                               mergeCollections=None, stream=True,
                                owner=None, host=None, port=None,
                                session=requests.session(), **kwargs):
     """get all the matches involving a specific tile
@@ -529,6 +488,8 @@ def get_matches_involving_tile(matchCollection, groupId, id,
         id to query
     mergeCollections : :obj:`list` of :obj:`str`, optional
         other matchCollections to aggregate into answer
+    stream: bool
+        whether to invoke streaming on get (default True)
     owner : unicode
         matchCollection owner (fallback to render.DEFAULT_OWNER)
         (note match owner != stack owner always)
@@ -552,13 +513,8 @@ def get_matches_involving_tile(matchCollection, groupId, id,
             owner, matchCollection, groupId, id)
     request_url = add_merge_collections(request_url, mergeCollections)
 
-    r = session.get(request_url)
-    try:
-        return r.json()
-    except Exception as e:
-        logger.error(e)
-        logger.error(r.text)
-        raise RenderError(r.text)
+    return get_json(session,request_url,stream=stream)
+
 
 
 @renderaccess
@@ -604,14 +560,8 @@ def delete_point_matches_between_groups(matchCollection, pGroupId, qGroupId,
     request_url = format_baseurl(host, port) + \
         "/owner/{}/matchCollection/{}/group/{}/matchesWith/{}".format(
             owner, matchCollection, pGroupId, qGroupId)
-    try:
-        r = session.delete(request_url)
-        return r
-    except Exception as e:
-        logger.error(e)
-        logger.error(request_url)
-        logger.error(r.text)
-        raise RenderError(r.text)
+    r = rest_delete(session,request_url)
+
 
 
 @renderaccess
@@ -644,11 +594,7 @@ def import_matches(matchCollection, data, owner=None, host=None, port=None,
     request_url = format_baseurl(host, port) + \
         "/owner/%s/matchCollection/%s/matches" % (owner, matchCollection)
     logger.debug(request_url)
-    if not isinstance(data, str):
-        data = json.dumps(data)
-    r = session.put(request_url, data=data, headers={
-        "content-type": "application/json", "Accept": "application/json"})
-    return r
+    return put_json(session,request_url,data)
 
 
 @renderaccess
@@ -684,12 +630,5 @@ def delete_collection(matchCollection, owner=None, host=None, port=None,
     request_url = format_baseurl(host, port) + \
         "/owner/%s/matchCollection/%s" % (owner, matchCollection)
     logger.debug(request_url)
-    try:
-        r = session.delete(request_url)
-        return r
-    except Exception as e:
-        logger.error(e)
-        logger.error(request_url)
-        logger.error(r.text)
-        raise RenderError(r.text)
+    r = rest_delete(session,request_url)
 
