@@ -2,9 +2,10 @@
 import logging
 import os
 import requests
-from .utils import defaultifNone, NullHandler, fitargspec
+from .utils import defaultifNone, NullHandler, fitargspec, get_json
 from .errors import ClientScriptError, RenderError
 from decorator import decorator
+from six.moves import input as raw_input
 
 logger = logging.getLogger(__name__)
 logger.addHandler(NullHandler())
@@ -482,13 +483,8 @@ def get_owners(host=None, port=None, session=requests.session(),
 
     """
     request_url = "%s/owners/" % format_baseurl(host, port)
-    r = session.get(request_url)
-    try:
-        return r.json()
-    except Exception as e:
-        logger.error(e)
-        logger.error(r.text)
-        raise RenderError(r.text)
+    return get_json(session,request_url)
+
 
 
 @renderaccess
@@ -517,13 +513,8 @@ def get_stack_metadata_by_owner(owner=None, host=None, port=None,
     request_url = "%s/owner/%s/stacks/" % (
         format_baseurl(host, port), owner)
     logger.debug(request_url)
-    r = session.get(request_url)
-    try:
-        return r.json()
-    except Exception as e:
-        logger.error(e)
-        logger.error(r.text)
-        raise RenderError(r.text)
+    return get_json(session,request_url)
+
 
 
 @renderaccess
